# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, List

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.configuration import Configuration
from datadog_api_client.v2.model.aws_cur_configs_response import AwsCURConfigsResponse
from datadog_api_client.v2.model.aws_cur_config_response import AwsCURConfigResponse
from datadog_api_client.v2.model.aws_cur_config_post_request import AwsCURConfigPostRequest
from datadog_api_client.v2.model.aws_cur_config_patch_request import AwsCURConfigPatchRequest
from datadog_api_client.v2.model.azure_uc_configs_response import AzureUCConfigsResponse
from datadog_api_client.v2.model.azure_uc_config_pairs_response import AzureUCConfigPairsResponse
from datadog_api_client.v2.model.azure_uc_config_post_request import AzureUCConfigPostRequest
from datadog_api_client.v2.model.azure_uc_config_patch_request import AzureUCConfigPatchRequest
from datadog_api_client.v2.model.custom_costs_file_list_response import CustomCostsFileListResponse
from datadog_api_client.v2.model.custom_costs_file_upload_response import CustomCostsFileUploadResponse
from datadog_api_client.v2.model.custom_costs_file_line_item import CustomCostsFileLineItem
from datadog_api_client.v2.model.custom_costs_file_get_response import CustomCostsFileGetResponse


class CloudCostManagementApi:
    """
    The Cloud Cost Management API allows you to set up, edit, and delete Cloud Cost Management accounts for AWS and Azure. You can query your cost data by using the `Metrics endpoint <https://docs.datadoghq.com/api/latest/metrics/#query-timeseries-data-across-multiple-products>`_ and the ``cloud_cost`` data source. For more information, see the `Cloud Cost Management documentation <https://docs.datadoghq.com/cloud_cost_management/>`_.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient(Configuration())
        self.api_client = api_client

        self._create_cost_awscur_config_endpoint = _Endpoint(
            settings={
                "response_type": (AwsCURConfigResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/cost/aws_cur_config",
                "operation_id": "create_cost_awscur_config",
                "http_method": "POST",
                "version": "v2",
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (AwsCURConfigPostRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._create_cost_azure_uc_configs_endpoint = _Endpoint(
            settings={
                "response_type": (AzureUCConfigPairsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/cost/azure_uc_config",
                "operation_id": "create_cost_azure_uc_configs",
                "http_method": "POST",
                "version": "v2",
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (AzureUCConfigPostRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_cost_awscur_config_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/cost/aws_cur_config/{cloud_account_id}",
                "operation_id": "delete_cost_awscur_config",
                "http_method": "DELETE",
                "version": "v2",
            },
            params_map={
                "cloud_account_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "cloud_account_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["*/*"],
            },
            api_client=api_client,
        )

        self._delete_cost_azure_uc_config_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/cost/azure_uc_config/{cloud_account_id}",
                "operation_id": "delete_cost_azure_uc_config",
                "http_method": "DELETE",
                "version": "v2",
            },
            params_map={
                "cloud_account_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "cloud_account_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["*/*"],
            },
            api_client=api_client,
        )

        self._delete_custom_costs_file_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/cost/custom_costs/{file_id}",
                "operation_id": "delete_custom_costs_file",
                "http_method": "DELETE",
                "version": "v2",
            },
            params_map={
                "file_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "file_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["*/*"],
            },
            api_client=api_client,
        )

        self._get_custom_costs_file_endpoint = _Endpoint(
            settings={
                "response_type": (CustomCostsFileGetResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/cost/custom_costs/{file_id}",
                "operation_id": "get_custom_costs_file",
                "http_method": "GET",
                "version": "v2",
            },
            params_map={
                "file_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "file_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
            },
            api_client=api_client,
        )

        self._list_cost_awscur_configs_endpoint = _Endpoint(
            settings={
                "response_type": (AwsCURConfigsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/cost/aws_cur_config",
                "operation_id": "list_cost_awscur_configs",
                "http_method": "GET",
                "version": "v2",
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
            },
            api_client=api_client,
        )

        self._list_cost_azure_uc_configs_endpoint = _Endpoint(
            settings={
                "response_type": (AzureUCConfigsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/cost/azure_uc_config",
                "operation_id": "list_cost_azure_uc_configs",
                "http_method": "GET",
                "version": "v2",
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
            },
            api_client=api_client,
        )

        self._list_custom_costs_files_endpoint = _Endpoint(
            settings={
                "response_type": (CustomCostsFileListResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/cost/custom_costs",
                "operation_id": "list_custom_costs_files",
                "http_method": "GET",
                "version": "v2",
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
            },
            api_client=api_client,
        )

        self._update_cost_awscur_config_endpoint = _Endpoint(
            settings={
                "response_type": (AwsCURConfigsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/cost/aws_cur_config/{cloud_account_id}",
                "operation_id": "update_cost_awscur_config",
                "http_method": "PATCH",
                "version": "v2",
            },
            params_map={
                "cloud_account_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "cloud_account_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (AwsCURConfigPatchRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._update_cost_azure_uc_configs_endpoint = _Endpoint(
            settings={
                "response_type": (AzureUCConfigPairsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/cost/azure_uc_config/{cloud_account_id}",
                "operation_id": "update_cost_azure_uc_configs",
                "http_method": "PATCH",
                "version": "v2",
            },
            params_map={
                "cloud_account_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "cloud_account_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (AzureUCConfigPatchRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._upload_custom_costs_file_endpoint = _Endpoint(
            settings={
                "response_type": (CustomCostsFileUploadResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/cost/custom_costs",
                "operation_id": "upload_custom_costs_file",
                "http_method": "PUT",
                "version": "v2",
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": ([CustomCostsFileLineItem],),
                    "location": "body",
                    "collection_format": "multi",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_cost_awscur_config(
        self,
        body: AwsCURConfigPostRequest,
    ) -> AwsCURConfigResponse:
        """Create Cloud Cost Management AWS CUR config.

        Create a Cloud Cost Management account for an AWS CUR config.

        :type body: AwsCURConfigPostRequest
        :rtype: AwsCURConfigResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_cost_awscur_config_endpoint.call_with_http_info(**kwargs)

    def create_cost_azure_uc_configs(
        self,
        body: AzureUCConfigPostRequest,
    ) -> AzureUCConfigPairsResponse:
        """Create Cloud Cost Management Azure configs.

        Create a Cloud Cost Management account for an Azure config.

        :type body: AzureUCConfigPostRequest
        :rtype: AzureUCConfigPairsResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_cost_azure_uc_configs_endpoint.call_with_http_info(**kwargs)

    def delete_cost_awscur_config(
        self,
        cloud_account_id: str,
    ) -> None:
        """Delete Cloud Cost Management AWS CUR config.

        Archive a Cloud Cost Management Account.

        :param cloud_account_id: Cloud Account id.
        :type cloud_account_id: str
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["cloud_account_id"] = cloud_account_id

        return self._delete_cost_awscur_config_endpoint.call_with_http_info(**kwargs)

    def delete_cost_azure_uc_config(
        self,
        cloud_account_id: str,
    ) -> None:
        """Delete Cloud Cost Management Azure config.

        Archive a Cloud Cost Management Account.

        :param cloud_account_id: Cloud Account id.
        :type cloud_account_id: str
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["cloud_account_id"] = cloud_account_id

        return self._delete_cost_azure_uc_config_endpoint.call_with_http_info(**kwargs)

    def delete_custom_costs_file(
        self,
        file_id: str,
    ) -> None:
        """Delete Custom Costs file.

        Delete the specified Custom Costs file.

        :param file_id: File ID.
        :type file_id: str
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["file_id"] = file_id

        return self._delete_custom_costs_file_endpoint.call_with_http_info(**kwargs)

    def get_custom_costs_file(
        self,
        file_id: str,
    ) -> CustomCostsFileGetResponse:
        """Get Custom Costs file.

        Fetch the specified Custom Costs file.

        :param file_id: File ID.
        :type file_id: str
        :rtype: CustomCostsFileGetResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["file_id"] = file_id

        return self._get_custom_costs_file_endpoint.call_with_http_info(**kwargs)

    def list_cost_awscur_configs(
        self,
    ) -> AwsCURConfigsResponse:
        """List Cloud Cost Management AWS CUR configs.

        List the AWS CUR configs.

        :rtype: AwsCURConfigsResponse
        """
        kwargs: Dict[str, Any] = {}
        return self._list_cost_awscur_configs_endpoint.call_with_http_info(**kwargs)

    def list_cost_azure_uc_configs(
        self,
    ) -> AzureUCConfigsResponse:
        """List Cloud Cost Management Azure configs.

        List the Azure configs.

        :rtype: AzureUCConfigsResponse
        """
        kwargs: Dict[str, Any] = {}
        return self._list_cost_azure_uc_configs_endpoint.call_with_http_info(**kwargs)

    def list_custom_costs_files(
        self,
    ) -> CustomCostsFileListResponse:
        """List Custom Costs files.

        List the Custom Costs files.

        :rtype: CustomCostsFileListResponse
        """
        kwargs: Dict[str, Any] = {}
        return self._list_custom_costs_files_endpoint.call_with_http_info(**kwargs)

    def update_cost_awscur_config(
        self,
        cloud_account_id: str,
        body: AwsCURConfigPatchRequest,
    ) -> AwsCURConfigsResponse:
        """Update Cloud Cost Management AWS CUR config.

        Update the status (active/archived) and/or account filtering configuration of an AWS CUR config.

        :param cloud_account_id: Cloud Account id.
        :type cloud_account_id: str
        :type body: AwsCURConfigPatchRequest
        :rtype: AwsCURConfigsResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["cloud_account_id"] = cloud_account_id

        kwargs["body"] = body

        return self._update_cost_awscur_config_endpoint.call_with_http_info(**kwargs)

    def update_cost_azure_uc_configs(
        self,
        cloud_account_id: str,
        body: AzureUCConfigPatchRequest,
    ) -> AzureUCConfigPairsResponse:
        """Update Cloud Cost Management Azure config.

        Update the status of an  Azure config (active/archived).

        :param cloud_account_id: Cloud Account id.
        :type cloud_account_id: str
        :type body: AzureUCConfigPatchRequest
        :rtype: AzureUCConfigPairsResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["cloud_account_id"] = cloud_account_id

        kwargs["body"] = body

        return self._update_cost_azure_uc_configs_endpoint.call_with_http_info(**kwargs)

    def upload_custom_costs_file(
        self,
        body: List[CustomCostsFileLineItem],
    ) -> CustomCostsFileUploadResponse:
        """Upload Custom Costs file.

        Upload a Custom Costs file.

        :type body: [CustomCostsFileLineItem]
        :rtype: CustomCostsFileUploadResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._upload_custom_costs_file_endpoint.call_with_http_info(**kwargs)
