# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class FindingVulnerabilityType(ModelSimple):
    """
    The vulnerability type of the finding.

    :param value: Must be one of ["misconfiguration", "attack_path", "identity_risk", "api_security"].
    :type value: str
    """

    allowed_values = {
        "misconfiguration",
        "attack_path",
        "identity_risk",
        "api_security",
    }
    MISCONFIGURATION: ClassVar["FindingVulnerabilityType"]
    ATTACK_PATH: ClassVar["FindingVulnerabilityType"]
    IDENTITY_RISK: ClassVar["FindingVulnerabilityType"]
    API_SECURITY: ClassVar["FindingVulnerabilityType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


FindingVulnerabilityType.MISCONFIGURATION = FindingVulnerabilityType("misconfiguration")
FindingVulnerabilityType.ATTACK_PATH = FindingVulnerabilityType("attack_path")
FindingVulnerabilityType.IDENTITY_RISK = FindingVulnerabilityType("identity_risk")
FindingVulnerabilityType.API_SECURITY = FindingVulnerabilityType("api_security")
